package com.hp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.CustomerServiceProviderEnterpriseVO;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.entity.Result;
import com.hp.user.client.service.CustomerServiceProviderEnterpriseService;
import com.hp.user.service.dao.CustomerServiceProviderEnterpriseMapper;
import com.hp.user.service.entity.CustomerServiceProviderEnterprise;
import com.hp.user.service.entity.Station;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 企业和服务商的关系 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class CustomerServiceProviderEnterpriseServiceImpl implements CustomerServiceProviderEnterpriseService {
    @Autowired
    private CustomerServiceProviderEnterpriseMapper csMapper;

    @Override
    public Result insert(CustomerServiceProviderEnterpriseVO cs) {
        CustomerServiceProviderEnterprise temp = new CustomerServiceProviderEnterprise();
        Result result = new Result();
        int flag = 0;
        try {
            BeanUtils.copyProperties(cs, temp);
            flag = csMapper.insert(temp);
        } catch (Exception e) {

        }
        // 判断数据库操作是否成功
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("添加失败");
        }
        return result;
    }

    @Override
    public Result update(CustomerServiceProviderEnterpriseVO cs) {
        CustomerServiceProviderEnterprise temp = new CustomerServiceProviderEnterprise();
        Result result = new Result();
        int flag = 0;
        try {
            BeanUtils.copyProperties(cs, temp);
            flag = csMapper.updateById(temp);
        } catch (Exception e) {

        }
        // 判断数据库操作是否成功
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("更新失败");
        }
        return result;
    }

    @Override
    public Result delete(String csId) {
        Result result = new Result();
        int flag = 0;
        try {
            flag = csMapper.deleteById(csId);
        } catch (Exception e) {

        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
        }
        return result;
    }

    @Override
    public Result deleteByServiceProviderId(String serviceProviderId) {
        Result result = new Result();
        int flag=0;
        Map<String, Object> map = new HashMap<>();
        map.put("service_provider_id",serviceProviderId);
        try{
            flag=csMapper.deleteByMap(map);
        }catch (Exception e){

        }if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
        }
        return result;
    }

    @Override
    public DataResult<CustomerServiceProviderEnterpriseVO> queryCsByCompanyIdAndServiceProviderId(String companyId, String serviceProviderId) {
        DataResult<CustomerServiceProviderEnterpriseVO> result = new DataResult<>();
        QueryWrapper<CustomerServiceProviderEnterprise> wrapper = new QueryWrapper<>();
        try {
            if (companyId == null || serviceProviderId == null) {
                result.setCode("-1");
                result.setMessage("未填写企业Id/服务商Id");
                return result;
            }
            wrapper.eq("service_provider_id", serviceProviderId);
            wrapper.eq("enterprise_id", companyId);
            CustomerServiceProviderEnterprise cs = csMapper.selectOne(wrapper);
            CustomerServiceProviderEnterpriseVO temp = new CustomerServiceProviderEnterpriseVO();
            if (cs == null) {
                result.setCode("-1");
                result.setMessage("该企业不属于此服务商");
                return result;
            } else {
                BeanUtils.copyProperties(cs, temp);
                result.setCode("0");
                result.setData(temp);
            }
        } catch (Exception e) {

        }
        return result;
    }

    @Override
    public DataResult<CustomerServiceProviderEnterpriseVO> queryCsByCompanyId(String companyId){
        DataResult<CustomerServiceProviderEnterpriseVO> result = new DataResult<>();
        QueryWrapper<CustomerServiceProviderEnterprise> wrapper = new QueryWrapper<>();
        try {
            if (companyId == null){
                result.setCode("-1");
                result.setMessage("企业Id不能为空");
                return result;
            }
            wrapper.eq("enterprise_id", companyId);
            CustomerServiceProviderEnterprise cs = csMapper.selectOne(wrapper);
            CustomerServiceProviderEnterpriseVO temp = new CustomerServiceProviderEnterpriseVO();
            if (cs == null) {
                result.setCode("-1");
                result.setMessage("未查找到企业对应的服务商关系");
                return result;
            }
            else {
                BeanUtils.copyProperties(cs, temp);
                result.setCode("0");
                result.setData(temp);
            }
        } catch (Exception e) {

        }
        return result;
    }

    @Override
    public Result insertBatch(List<CustomerServiceProviderEnterpriseVO> csVOList) {
        Result result = new Result();
        int flag = 0;
        List<CustomerServiceProviderEnterprise> csList = new ArrayList<>();
        CustomerServiceProviderEnterprise temp;
        try{
            for (CustomerServiceProviderEnterpriseVO cs : csVOList) {
                temp = new CustomerServiceProviderEnterprise();
                BeanUtils.copyProperties(cs, temp);
                csList.add(temp);
            }
            flag = csMapper.insertBatch(csList);
        }catch (Exception e){

        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("添加失败");
        }
        return result;
    }

    @Override
    public Result deleteBatch(List<String> enterpriseIdList) {
        Result result = new Result();
        int flag=0;
        try{
            flag = csMapper.deleteBatch(enterpriseIdList);
        }catch(Exception e){

        }
        if (SqlHelper.retBool(flag)) {
            result.setCode("0");
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
        }
        return result;
    }
}
